@@ -9,6 +9,7 @@
 #' @return Result of the job.
 #' @export
 #' @examples
+#' \dontshow{ batchtools:::example_push_temp(1) }
 #' tmp = makeRegistry(file.dir = NA, make.default = FALSE)
 #' batchMap(identity, 1:2, reg = tmp)
 #' job = makeJob(1, reg = tmp)
@@ -32,6 +33,7 @@ execJob.JobCollection = function(job) {
 #' @export
 execJob.Job = function(job) {
   local_options(list(error = function(e) traceback(2L)))
+  messagef("### [bt%s]: Setting seed to %i ...", now(), job$id, job$seed)
   if (".job" %chin% names(formals(job$fun))) {
     with_seed(job$seed, do.call(job$fun, c(job$pars, list(.job = job)), envir = .GlobalEnv))
   } else {
@@ -42,12 +44,12 @@ execJob.Job = function(job) {
 #' @export
 execJob.Experiment = function(job) {
   local_options(list(error = function(e) traceback(2L)))
-  catf("Generating problem instance for problem '%s' ...", job$prob.name)
+  messagef("### [bt%s]: Generating problem instance for problem '%s' ...", now(), job$prob.name)
   instance = job$instance
   force(instance)
   job$allow.access.to.instance = FALSE
 
-  catf("Applying algorithm '%s' on problem '%s' ...", job$algo.name, job$prob.name)
   wrapper = function(...) job$algorithm$fun(job = job, data = job$problem$data, instance = instance, ...)
+  messagef("### [bt%s]: Applying algorithm '%s' on problem '%s' for job %i (seed = %i) ...", now(), job$algo.name, job$prob.name, job$id, job$seed)
   with_seed(job$seed, do.call(wrapper, job$algo.pars, envir = .GlobalEnv))
 }
