@@ -44,12 +44,6 @@ file_remove = function(x) {
   }
 }
 
-path_real = function(path) {
-  if (fs::is_absolute_path(path))
-    return(fs::path_norm(path))
-  fs::path_real(path)
-}
-
 file_mtime = function(x) {
   fs::file_info(x)$modification_time
 }
